@@ -2,6 +2,11 @@ import os
 
 # A manifest of the included packages.
 lambda_packages = {
+    'cffi': {
+        'version': '1.7.0',
+        'path': os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                             'cffi', 'cffi-1.7.0.tar.gz')
+    },
     'cv2': {
         'version': '3.1.0',
         'path': os.path.join(os.path.dirname(os.path.abspath(__file__)), 'OpenCV', 'OpenCV-3.1.0.tar.gz')
@@ -25,5 +30,15 @@ lambda_packages = {
     'psycopg2': {
         'version': '2.6.1',
         'path': os.path.join(os.path.dirname(os.path.abspath(__file__)), 'psycopg2', 'psycopg2-2.6.1.tar.gz')
+    },
+    'pycrypto': {
+        'version': '2.6.1',
+        'path': os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                             'pycrypto', 'pycrypto-2.6.1.tar.gz')
+    },
+    'pynacl': {
+        'version': '1.0.1',
+        'path': os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                             'PyNaCl', 'PyNaCl-1.0.1.tar.gz')
     }
 }
